/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence;

import com.topcoder.util.config.ConfigManager;

import java.util.Iterator;


/**
 * A helper class to provide some useful methods for setting up the configuration namespaces.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class ConfigHelper {
    /**
     * The configuration file of the document index persistence.
     */
    public static final String CONFIG_FILE = "config.xml";

    /**
     * The namespace of the document index persistence pertaining to the Informix database.
     */
    public static final String DB_NAMESPACE = "com.topcoder.document.index.persistence.impl.db";

    /**
     * The namespace of the document index persistence pertaining to the xml file.
     */
    public static final String XML_NAMESPACE = "com.topcoder.document.index.persistence.impl.xml";

    /**
     * The namespace of the db connection factory.
     */
    public static final String CONNECTION_NAMESPACE = "com.topcoder.db.connectionfactory";

    /**
     * The connection producer name used to obtain the connection.
     */
    public static final String CONNECTION_PRODUCER_NAME = "Informix_Connection_Producer";

    /**
     * The bad configuration file of the document index persistence.
     */
    public static final String BAD_CONFIG_FILE = "badconfig.xml";

    /**
     * The bad namespaces used by the database persistence.
     */
    public static final String[] BAD_DB_NAMESPACES = {"baddb1", "baddb2", "baddb3"};

    /**
     * The bad namespaces used by the xml persistence.
     */
    public static final String[] BAD_XML_NAMESPACES =
        {"badxml1", "badxml2", "badxml3", "badxml4", "badxml5", "badxml6"};

    /**
     * Private constructor to prevent instantiation.
     */
    private ConfigHelper() {
    }

    /**
     * Loads the namespaces of document index persistence.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public static void loadConfig() throws Exception {
        unloadConfig();
        ConfigManager.getInstance().add(CONFIG_FILE);
        ConfigManager.getInstance().add(BAD_CONFIG_FILE);
    }

    /**
     * Clears all the namespaces.
     *
     * @throws Exception if any unexpected exception occurs.
     */
    public static void unloadConfig() throws Exception {
        ConfigManager config = ConfigManager.getInstance();

        for (Iterator i = config.getAllNamespaces(); i.hasNext();) {
            config.removeNamespace((String) i.next());
        }
    }
}
